@@ -34,7 +34,7 @@ class TestXUnitPlugin(PluginTester, unittest.TestCase):
         
         assert '<?xml version="1.0" encoding="UTF-8"?>' in result
         assert '<testsuite name="nosetests" tests="6" errors="2" failures="1" skip="1">' in result
-        assert '<testcase classname="test_xunit_as_suite.TestForXunit" name="test_error" time="0">' in result
+        assert '<testcase classname="test_xunit_as_suite.TestForXunit" name="test_error" time="' in result
         # TODO(Kumar) think of better x-platform code here that
         # does not confuse 2to3
         if sys.version_info[0:2] >= (3,0):
